#[repr(C)]pub struct VkApplicationInfo {
pub sType: VkStructureType,
pub pNext: *const c_void,
pub pApplicationName: *const c_char,
pub applicationVersion: u32,
pub pEngineName: *const c_char,
pub engineVersion: u32,
pub apiVersion: u32,
}Fields
sType: VkStructureTypepNext: *const c_voidpApplicationName: *const c_charapplicationVersion: u32pEngineName: *const c_charengineVersion: u32apiVersion: u32Trait Implementations
Sourceimpl Clone for VkApplicationInfo
impl Clone for VkApplicationInfo
Sourcefn clone(&self) -> VkApplicationInfo
fn clone(&self) -> VkApplicationInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VkApplicationInfo
impl Debug for VkApplicationInfo
Sourceimpl TypedVulkanStructure for VkApplicationInfo
impl TypedVulkanStructure for VkApplicationInfo
Sourceconst TYPE: VkStructureType = 0i32
const TYPE: VkStructureType = 0i32
sType of this structure
Sourcefn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
fn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
Cast structure ref only if sType matches
Sourceimpl VulkanStructure for VkApplicationInfo
impl VulkanStructure for VkApplicationInfo
Sourcefn as_generic(&self) -> &GenericVulkanStructure
fn as_generic(&self) -> &GenericVulkanStructure
Cast structure ref to generic. This is same as transmute but must be safe.
Sourcefn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
fn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
Cast structure mutable ref to generic. This is same as transmute but must be safe.