#[repr(C)]pub struct VkBindBufferMemoryInfoKHR {
pub sType: VkStructureType,
pub pNext: *const c_void,
pub buffer: VkBuffer,
pub memory: VkDeviceMemory,
pub memoryOffset: VkDeviceSize,
}Fields
sType: VkStructureTypepNext: *const c_voidbuffer: VkBuffermemory: VkDeviceMemorymemoryOffset: VkDeviceSizeTrait Implementations
Sourceimpl Clone for VkBindBufferMemoryInfoKHR
impl Clone for VkBindBufferMemoryInfoKHR
Sourcefn clone(&self) -> VkBindBufferMemoryInfoKHR
fn clone(&self) -> VkBindBufferMemoryInfoKHR
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VkBindBufferMemoryInfoKHR
impl Debug for VkBindBufferMemoryInfoKHR
Sourceimpl TypedVulkanStructure for VkBindBufferMemoryInfoKHR
impl TypedVulkanStructure for VkBindBufferMemoryInfoKHR
Sourceconst TYPE: VkStructureType = 1_000_157_000i32
const TYPE: VkStructureType = 1_000_157_000i32
sType of this structure
Sourcefn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
fn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
Cast structure ref only if sType matches
Sourceimpl VulkanStructure for VkBindBufferMemoryInfoKHR
impl VulkanStructure for VkBindBufferMemoryInfoKHR
Sourcefn as_generic(&self) -> &GenericVulkanStructure
fn as_generic(&self) -> &GenericVulkanStructure
Cast structure ref to generic. This is same as transmute but must be safe.
Sourcefn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
fn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
Cast structure mutable ref to generic. This is same as transmute but must be safe.