#[repr(C)]pub struct VkBindImageMemoryInfoKHR {
pub sType: VkStructureType,
pub pNext: *const c_void,
pub image: VkImage,
pub memory: VkDeviceMemory,
pub memoryOffset: VkDeviceSize,
}Fields
sType: VkStructureTypepNext: *const c_voidimage: VkImagememory: VkDeviceMemorymemoryOffset: VkDeviceSizeTrait Implementations
Sourceimpl Clone for VkBindImageMemoryInfoKHR
impl Clone for VkBindImageMemoryInfoKHR
Sourcefn clone(&self) -> VkBindImageMemoryInfoKHR
fn clone(&self) -> VkBindImageMemoryInfoKHR
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VkBindImageMemoryInfoKHR
impl Debug for VkBindImageMemoryInfoKHR
Sourceimpl TypedVulkanStructure for VkBindImageMemoryInfoKHR
impl TypedVulkanStructure for VkBindImageMemoryInfoKHR
Sourceconst TYPE: VkStructureType = 1_000_157_001i32
const TYPE: VkStructureType = 1_000_157_001i32
sType of this structure
Sourcefn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
fn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
Cast structure ref only if sType matches
Sourceimpl VulkanStructure for VkBindImageMemoryInfoKHR
impl VulkanStructure for VkBindImageMemoryInfoKHR
Sourcefn as_generic(&self) -> &GenericVulkanStructure
fn as_generic(&self) -> &GenericVulkanStructure
Cast structure ref to generic. This is same as transmute but must be safe.
Sourcefn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
fn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
Cast structure mutable ref to generic. This is same as transmute but must be safe.