#[repr(C)]pub struct VkBindSparseInfo {
pub sType: VkStructureType,
pub pNext: *const c_void,
pub waitSemaphoreCount: u32,
pub pWaitSemaphores: *const VkSemaphore,
pub bufferBindCount: u32,
pub pBufferBinds: *const VkSparseBufferMemoryBindInfo,
pub imageOpaqueBindCount: u32,
pub pImageOpaqueBinds: *const VkSparseImageOpaqueMemoryBindInfo,
pub imageBindCount: u32,
pub pImageBinds: *const VkSparseImageMemoryBindInfo,
pub signalSemaphoreCount: u32,
pub pSignalSemaphores: *const VkSemaphore,
}Fields
sType: VkStructureTypepNext: *const c_voidwaitSemaphoreCount: u32pWaitSemaphores: *const VkSemaphorebufferBindCount: u32pBufferBinds: *const VkSparseBufferMemoryBindInfoimageOpaqueBindCount: u32pImageOpaqueBinds: *const VkSparseImageOpaqueMemoryBindInfoimageBindCount: u32pImageBinds: *const VkSparseImageMemoryBindInfosignalSemaphoreCount: u32pSignalSemaphores: *const VkSemaphoreTrait Implementations
Sourceimpl Clone for VkBindSparseInfo
impl Clone for VkBindSparseInfo
Sourcefn clone(&self) -> VkBindSparseInfo
fn clone(&self) -> VkBindSparseInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VkBindSparseInfo
impl Debug for VkBindSparseInfo
Sourceimpl SparseBindingOpBatch for VkBindSparseInfo
impl SparseBindingOpBatch for VkBindSparseInfo
fn make_info_struct(&self) -> VkBindSparseInfo
fn with_buffer_binds<'d>(
self,
buffer_binds: &'d [VkSparseBufferMemoryBindInfo],
) -> SparseBindingOpBatchWithBufferBinds<'d, Self>where
Self: Sized,
fn with_image_binds<'d>(
self,
buffer_binds: &'d [VkSparseImageMemoryBindInfo],
) -> SparseBindingOpBatchWithImageBinds<'d, Self>where
Self: Sized,
fn with_image_opaque_binds<'d>(
self,
buffer_binds: &'d [VkSparseImageOpaqueMemoryBindInfo],
) -> SparseBindingOpBatchWithImageOpaqueBinds<'d, Self>where
Self: Sized,
fn with_wait_semaphores<'d, Semaphore: Semaphore + 'd>(
self,
semaphores: &'d [Semaphore],
) -> SparseBindingOpBatchWithWaitSemaphores<'d, Self, Semaphore>where
Self: Sized,
fn with_signal_semaphores<'d, Semaphore: Semaphore + 'd>(
self,
semaphores: &'d [Semaphore],
) -> SparseBindingOpBatchWithSignalSemaphores<'d, Self, Semaphore>where
Self: Sized,
Sourceimpl TypedVulkanStructure for VkBindSparseInfo
impl TypedVulkanStructure for VkBindSparseInfo
Sourceconst TYPE: VkStructureType = 7i32
const TYPE: VkStructureType = 7i32
sType of this structure
Sourcefn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
fn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
Cast structure ref only if sType matches
Sourceimpl VulkanStructure for VkBindSparseInfo
impl VulkanStructure for VkBindSparseInfo
Sourcefn as_generic(&self) -> &GenericVulkanStructure
fn as_generic(&self) -> &GenericVulkanStructure
Cast structure ref to generic. This is same as transmute but must be safe.
Sourcefn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
fn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
Cast structure mutable ref to generic. This is same as transmute but must be safe.