#[repr(C)]pub struct VkBufferCreateInfo {
pub sType: VkStructureType,
pub pNext: *const c_void,
pub flags: VkBufferCreateFlags,
pub size: VkDeviceSize,
pub usage: VkBufferUsageFlags,
pub sharingMode: VkSharingMode,
pub queueFamilyIndexCount: u32,
pub pQueueFamilyIndices: *const u32,
}Fields
sType: VkStructureTypepNext: *const c_voidflags: VkBufferCreateFlagssize: VkDeviceSizeusage: VkBufferUsageFlagssharingMode: VkSharingModequeueFamilyIndexCount: u32pQueueFamilyIndices: *const u32Trait Implementations
Sourceimpl Clone for VkBufferCreateInfo
impl Clone for VkBufferCreateInfo
Sourcefn clone(&self) -> VkBufferCreateInfo
fn clone(&self) -> VkBufferCreateInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VkBufferCreateInfo
impl Debug for VkBufferCreateInfo
Sourceimpl TypedVulkanStructure for VkBufferCreateInfo
impl TypedVulkanStructure for VkBufferCreateInfo
Sourceconst TYPE: VkStructureType = 12i32
const TYPE: VkStructureType = 12i32
sType of this structure
Sourcefn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
fn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
Cast structure ref only if sType matches
Sourceimpl VulkanStructure for VkBufferCreateInfo
impl VulkanStructure for VkBufferCreateInfo
Sourcefn as_generic(&self) -> &GenericVulkanStructure
fn as_generic(&self) -> &GenericVulkanStructure
Cast structure ref to generic. This is same as transmute but must be safe.
Sourcefn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
fn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
Cast structure mutable ref to generic. This is same as transmute but must be safe.