#[repr(C)]pub struct VkBufferViewCreateInfo {
pub sType: VkStructureType,
pub pNext: *const c_void,
pub flags: VkBufferViewCreateFlags,
pub buffer: VkBuffer,
pub format: VkFormat,
pub offset: VkDeviceSize,
pub range: VkDeviceSize,
}Fields
sType: VkStructureTypepNext: *const c_voidflags: VkBufferViewCreateFlagsbuffer: VkBufferformat: VkFormatoffset: VkDeviceSizerange: VkDeviceSizeTrait Implementations
Sourceimpl Clone for VkBufferViewCreateInfo
impl Clone for VkBufferViewCreateInfo
Sourcefn clone(&self) -> VkBufferViewCreateInfo
fn clone(&self) -> VkBufferViewCreateInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VkBufferViewCreateInfo
impl Debug for VkBufferViewCreateInfo
Sourceimpl TypedVulkanStructure for VkBufferViewCreateInfo
impl TypedVulkanStructure for VkBufferViewCreateInfo
Sourceconst TYPE: VkStructureType = 13i32
const TYPE: VkStructureType = 13i32
sType of this structure
Sourcefn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
fn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
Cast structure ref only if sType matches
Sourceimpl VulkanStructure for VkBufferViewCreateInfo
impl VulkanStructure for VkBufferViewCreateInfo
Sourcefn as_generic(&self) -> &GenericVulkanStructure
fn as_generic(&self) -> &GenericVulkanStructure
Cast structure ref to generic. This is same as transmute but must be safe.
Sourcefn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
fn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
Cast structure mutable ref to generic. This is same as transmute but must be safe.