#[repr(C)]pub struct VkCommandBufferAllocateInfo {
pub sType: VkStructureType,
pub pNext: *const c_void,
pub commandPool: VkCommandPool,
pub level: VkCommandBufferLevel,
pub commandBufferCount: u32,
}Fields
sType: VkStructureTypepNext: *const c_voidcommandPool: VkCommandPoollevel: VkCommandBufferLevelcommandBufferCount: u32Trait Implementations
Sourceimpl Clone for VkCommandBufferAllocateInfo
impl Clone for VkCommandBufferAllocateInfo
Sourcefn clone(&self) -> VkCommandBufferAllocateInfo
fn clone(&self) -> VkCommandBufferAllocateInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VkCommandBufferAllocateInfo
impl Debug for VkCommandBufferAllocateInfo
Sourceimpl TypedVulkanStructure for VkCommandBufferAllocateInfo
impl TypedVulkanStructure for VkCommandBufferAllocateInfo
Sourceconst TYPE: VkStructureType = 40i32
const TYPE: VkStructureType = 40i32
sType of this structure
Sourcefn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
fn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
Cast structure ref only if sType matches
Sourceimpl VulkanStructure for VkCommandBufferAllocateInfo
impl VulkanStructure for VkCommandBufferAllocateInfo
Sourcefn as_generic(&self) -> &GenericVulkanStructure
fn as_generic(&self) -> &GenericVulkanStructure
Cast structure ref to generic. This is same as transmute but must be safe.
Sourcefn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
fn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
Cast structure mutable ref to generic. This is same as transmute but must be safe.