#[repr(C)]pub struct VkCommandBufferBeginInfo {
pub sType: VkStructureType,
pub pNext: *const c_void,
pub flags: VkCommandBufferUsageFlags,
pub pInheritanceInfo: *const VkCommandBufferInheritanceInfo,
}Fields
sType: VkStructureTypepNext: *const c_voidflags: VkCommandBufferUsageFlagspInheritanceInfo: *const VkCommandBufferInheritanceInfoTrait Implementations
Sourceimpl Clone for VkCommandBufferBeginInfo
impl Clone for VkCommandBufferBeginInfo
Sourcefn clone(&self) -> VkCommandBufferBeginInfo
fn clone(&self) -> VkCommandBufferBeginInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VkCommandBufferBeginInfo
impl Debug for VkCommandBufferBeginInfo
Sourceimpl TypedVulkanStructure for VkCommandBufferBeginInfo
impl TypedVulkanStructure for VkCommandBufferBeginInfo
Sourceconst TYPE: VkStructureType = 42i32
const TYPE: VkStructureType = 42i32
sType of this structure
Sourcefn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
fn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
Cast structure ref only if sType matches
Sourceimpl VulkanStructure for VkCommandBufferBeginInfo
impl VulkanStructure for VkCommandBufferBeginInfo
Sourcefn as_generic(&self) -> &GenericVulkanStructure
fn as_generic(&self) -> &GenericVulkanStructure
Cast structure ref to generic. This is same as transmute but must be safe.
Sourcefn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
fn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
Cast structure mutable ref to generic. This is same as transmute but must be safe.