#[repr(C)]pub struct VkCommandBufferInheritanceInfo {
pub sType: VkStructureType,
pub pNext: *const c_void,
pub renderPass: VkRenderPass,
pub subpass: u32,
pub framebuffer: VkFramebuffer,
pub occlusionQueryEnable: VkBool32,
pub queryFlags: VkQueryControlFlags,
pub pipelineStatistics: VkQueryPipelineStatisticFlags,
}Fields
sType: VkStructureTypepNext: *const c_voidrenderPass: VkRenderPasssubpass: u32framebuffer: VkFramebufferocclusionQueryEnable: VkBool32queryFlags: VkQueryControlFlagspipelineStatistics: VkQueryPipelineStatisticFlagsTrait Implementations
Sourceimpl Clone for VkCommandBufferInheritanceInfo
impl Clone for VkCommandBufferInheritanceInfo
Sourcefn clone(&self) -> VkCommandBufferInheritanceInfo
fn clone(&self) -> VkCommandBufferInheritanceInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl TypedVulkanStructure for VkCommandBufferInheritanceInfo
impl TypedVulkanStructure for VkCommandBufferInheritanceInfo
Sourceconst TYPE: VkStructureType = 41i32
const TYPE: VkStructureType = 41i32
sType of this structure
Sourcefn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
fn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
Cast structure ref only if sType matches
Sourceimpl VulkanStructure for VkCommandBufferInheritanceInfo
impl VulkanStructure for VkCommandBufferInheritanceInfo
Sourcefn as_generic(&self) -> &GenericVulkanStructure
fn as_generic(&self) -> &GenericVulkanStructure
Cast structure ref to generic. This is same as transmute but must be safe.
Sourcefn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
fn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
Cast structure mutable ref to generic. This is same as transmute but must be safe.