#[repr(C)]pub struct VkCommandBufferSubmitInfoKHR {
pub sType: VkStructureType,
pub pNext: *const c_void,
pub commandBuffer: VkCommandBuffer,
pub deviceMask: u32,
}Fields
sType: VkStructureTypepNext: *const c_voidcommandBuffer: VkCommandBufferdeviceMask: u32Trait Implementations
Sourceimpl Clone for VkCommandBufferSubmitInfoKHR
impl Clone for VkCommandBufferSubmitInfoKHR
Sourcefn clone(&self) -> VkCommandBufferSubmitInfoKHR
fn clone(&self) -> VkCommandBufferSubmitInfoKHR
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VkCommandBufferSubmitInfoKHR
impl Debug for VkCommandBufferSubmitInfoKHR
Sourceimpl TypedVulkanStructure for VkCommandBufferSubmitInfoKHR
impl TypedVulkanStructure for VkCommandBufferSubmitInfoKHR
Sourceconst TYPE: VkStructureType = 1_000_314_006i32
const TYPE: VkStructureType = 1_000_314_006i32
sType of this structure
Sourcefn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
fn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
Cast structure ref only if sType matches
Sourceimpl VulkanStructure for VkCommandBufferSubmitInfoKHR
impl VulkanStructure for VkCommandBufferSubmitInfoKHR
Sourcefn as_generic(&self) -> &GenericVulkanStructure
fn as_generic(&self) -> &GenericVulkanStructure
Cast structure ref to generic. This is same as transmute but must be safe.
Sourcefn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
fn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
Cast structure mutable ref to generic. This is same as transmute but must be safe.