#[repr(C)]pub struct VkCommandPoolCreateInfo {
pub sType: VkStructureType,
pub pNext: *const c_void,
pub flags: VkCommandPoolCreateFlags,
pub queueFamilyIndex: u32,
}Fields
sType: VkStructureTypepNext: *const c_voidflags: VkCommandPoolCreateFlagsqueueFamilyIndex: u32Trait Implementations
Sourceimpl Clone for VkCommandPoolCreateInfo
impl Clone for VkCommandPoolCreateInfo
Sourcefn clone(&self) -> VkCommandPoolCreateInfo
fn clone(&self) -> VkCommandPoolCreateInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VkCommandPoolCreateInfo
impl Debug for VkCommandPoolCreateInfo
Sourceimpl TypedVulkanStructure for VkCommandPoolCreateInfo
impl TypedVulkanStructure for VkCommandPoolCreateInfo
Sourceconst TYPE: VkStructureType = 39i32
const TYPE: VkStructureType = 39i32
sType of this structure
Sourcefn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
fn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
Cast structure ref only if sType matches
Sourceimpl VulkanStructure for VkCommandPoolCreateInfo
impl VulkanStructure for VkCommandPoolCreateInfo
Sourcefn as_generic(&self) -> &GenericVulkanStructure
fn as_generic(&self) -> &GenericVulkanStructure
Cast structure ref to generic. This is same as transmute but must be safe.
Sourcefn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
fn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
Cast structure mutable ref to generic. This is same as transmute but must be safe.