#[repr(C)]pub struct VkComputePipelineCreateInfo {
pub sType: VkStructureType,
pub pNext: *const c_void,
pub flags: VkPipelineCreateFlags,
pub stage: VkPipelineShaderStageCreateInfo,
pub layout: VkPipelineLayout,
pub basePipelineHandle: VkPipeline,
pub basePipelineIndex: i32,
}Fields
sType: VkStructureTypepNext: *const c_voidflags: VkPipelineCreateFlagsstage: VkPipelineShaderStageCreateInfolayout: VkPipelineLayoutbasePipelineHandle: VkPipelinebasePipelineIndex: i32Trait Implementations
Sourceimpl Clone for VkComputePipelineCreateInfo
impl Clone for VkComputePipelineCreateInfo
Sourcefn clone(&self) -> VkComputePipelineCreateInfo
fn clone(&self) -> VkComputePipelineCreateInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VkComputePipelineCreateInfo
impl Debug for VkComputePipelineCreateInfo
Sourceimpl TypedVulkanStructure for VkComputePipelineCreateInfo
impl TypedVulkanStructure for VkComputePipelineCreateInfo
Sourceconst TYPE: VkStructureType = 29i32
const TYPE: VkStructureType = 29i32
sType of this structure
Sourcefn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
fn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
Cast structure ref only if sType matches
Sourceimpl VulkanStructure for VkComputePipelineCreateInfo
impl VulkanStructure for VkComputePipelineCreateInfo
Sourcefn as_generic(&self) -> &GenericVulkanStructure
fn as_generic(&self) -> &GenericVulkanStructure
Cast structure ref to generic. This is same as transmute but must be safe.
Sourcefn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
fn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
Cast structure mutable ref to generic. This is same as transmute but must be safe.