#[repr(C)]pub struct VkCopyDescriptorSet {
pub sType: VkStructureType,
pub pNext: *const c_void,
pub srcSet: VkDescriptorSet,
pub srcBinding: u32,
pub srcArrayElement: u32,
pub dstSet: VkDescriptorSet,
pub dstBinding: u32,
pub dstArrayElement: u32,
pub descriptorCount: u32,
}Fields
sType: VkStructureTypepNext: *const c_voidsrcSet: VkDescriptorSetsrcBinding: u32srcArrayElement: u32dstSet: VkDescriptorSetdstBinding: u32dstArrayElement: u32descriptorCount: u32Trait Implementations
Sourceimpl Clone for VkCopyDescriptorSet
impl Clone for VkCopyDescriptorSet
Sourcefn clone(&self) -> VkCopyDescriptorSet
fn clone(&self) -> VkCopyDescriptorSet
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VkCopyDescriptorSet
impl Debug for VkCopyDescriptorSet
Sourceimpl TypedVulkanStructure for VkCopyDescriptorSet
impl TypedVulkanStructure for VkCopyDescriptorSet
Sourceconst TYPE: VkStructureType = 36i32
const TYPE: VkStructureType = 36i32
sType of this structure
Sourcefn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
fn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
Cast structure ref only if sType matches
Sourceimpl VulkanStructure for VkCopyDescriptorSet
impl VulkanStructure for VkCopyDescriptorSet
Sourcefn as_generic(&self) -> &GenericVulkanStructure
fn as_generic(&self) -> &GenericVulkanStructure
Cast structure ref to generic. This is same as transmute but must be safe.
Sourcefn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
fn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
Cast structure mutable ref to generic. This is same as transmute but must be safe.