#[repr(C)]pub struct VkDescriptorSetAllocateInfo {
pub sType: VkStructureType,
pub pNext: *const c_void,
pub descriptorPool: VkDescriptorPool,
pub descriptorSetCount: u32,
pub pSetLayouts: *const VkDescriptorSetLayout,
}Fields
sType: VkStructureTypepNext: *const c_voiddescriptorPool: VkDescriptorPooldescriptorSetCount: u32pSetLayouts: *const VkDescriptorSetLayoutTrait Implementations
Sourceimpl Clone for VkDescriptorSetAllocateInfo
impl Clone for VkDescriptorSetAllocateInfo
Sourcefn clone(&self) -> VkDescriptorSetAllocateInfo
fn clone(&self) -> VkDescriptorSetAllocateInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VkDescriptorSetAllocateInfo
impl Debug for VkDescriptorSetAllocateInfo
Sourceimpl TypedVulkanStructure for VkDescriptorSetAllocateInfo
impl TypedVulkanStructure for VkDescriptorSetAllocateInfo
Sourceconst TYPE: VkStructureType = 34i32
const TYPE: VkStructureType = 34i32
sType of this structure
Sourcefn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
fn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
Cast structure ref only if sType matches
Sourceimpl VulkanStructure for VkDescriptorSetAllocateInfo
impl VulkanStructure for VkDescriptorSetAllocateInfo
Sourcefn as_generic(&self) -> &GenericVulkanStructure
fn as_generic(&self) -> &GenericVulkanStructure
Cast structure ref to generic. This is same as transmute but must be safe.
Sourcefn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
fn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
Cast structure mutable ref to generic. This is same as transmute but must be safe.