#[repr(C)]pub struct VkDescriptorSetLayoutCreateInfo {
pub sType: VkStructureType,
pub pNext: *const c_void,
pub flags: VkDescriptorSetLayoutCreateFlags,
pub bindingCount: u32,
pub pBindings: *const VkDescriptorSetLayoutBinding,
}Fields
sType: VkStructureTypepNext: *const c_voidflags: VkDescriptorSetLayoutCreateFlagsbindingCount: u32pBindings: *const VkDescriptorSetLayoutBindingTrait Implementations
Sourceimpl Clone for VkDescriptorSetLayoutCreateInfo
impl Clone for VkDescriptorSetLayoutCreateInfo
Sourcefn clone(&self) -> VkDescriptorSetLayoutCreateInfo
fn clone(&self) -> VkDescriptorSetLayoutCreateInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl TypedVulkanStructure for VkDescriptorSetLayoutCreateInfo
impl TypedVulkanStructure for VkDescriptorSetLayoutCreateInfo
Sourceconst TYPE: VkStructureType = 32i32
const TYPE: VkStructureType = 32i32
sType of this structure
Sourcefn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
fn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
Cast structure ref only if sType matches
Sourceimpl VulkanStructure for VkDescriptorSetLayoutCreateInfo
impl VulkanStructure for VkDescriptorSetLayoutCreateInfo
Sourcefn as_generic(&self) -> &GenericVulkanStructure
fn as_generic(&self) -> &GenericVulkanStructure
Cast structure ref to generic. This is same as transmute but must be safe.
Sourcefn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
fn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
Cast structure mutable ref to generic. This is same as transmute but must be safe.