#[repr(C)]pub struct VkDeviceCreateInfo {
pub sType: VkStructureType,
pub pNext: *const c_void,
pub flags: VkDeviceCreateFlags,
pub queueCreateInfoCount: u32,
pub pQueueCreateInfos: *const VkDeviceQueueCreateInfo,
pub enabledLayerCount: u32,
pub ppEnabledLayerNames: *const *const c_char,
pub enabledExtensionCount: u32,
pub ppEnabledExtensionNames: *const *const c_char,
pub pEnabledFeatures: *const VkPhysicalDeviceFeatures,
}Fields
sType: VkStructureTypepNext: *const c_voidflags: VkDeviceCreateFlagsqueueCreateInfoCount: u32pQueueCreateInfos: *const VkDeviceQueueCreateInfoenabledLayerCount: u32ppEnabledLayerNames: *const *const c_charenabledExtensionCount: u32ppEnabledExtensionNames: *const *const c_charpEnabledFeatures: *const VkPhysicalDeviceFeaturesTrait Implementations
Sourceimpl Clone for VkDeviceCreateInfo
impl Clone for VkDeviceCreateInfo
Sourcefn clone(&self) -> VkDeviceCreateInfo
fn clone(&self) -> VkDeviceCreateInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VkDeviceCreateInfo
impl Debug for VkDeviceCreateInfo
Sourceimpl TypedVulkanStructure for VkDeviceCreateInfo
impl TypedVulkanStructure for VkDeviceCreateInfo
Sourceconst TYPE: VkStructureType = 3i32
const TYPE: VkStructureType = 3i32
sType of this structure
Sourcefn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
fn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
Cast structure ref only if sType matches
Sourceimpl VulkanStructure for VkDeviceCreateInfo
impl VulkanStructure for VkDeviceCreateInfo
Sourcefn as_generic(&self) -> &GenericVulkanStructure
fn as_generic(&self) -> &GenericVulkanStructure
Cast structure ref to generic. This is same as transmute but must be safe.
Sourcefn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
fn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
Cast structure mutable ref to generic. This is same as transmute but must be safe.