#[repr(C)]pub struct VkDeviceQueueCreateInfo {
pub sType: VkStructureType,
pub pNext: *const c_void,
pub flags: VkDeviceQueueCreateFlags,
pub queueFamilyIndex: u32,
pub queueCount: u32,
pub pQueuePriorities: *const c_float,
}Fields
sType: VkStructureTypepNext: *const c_voidflags: VkDeviceQueueCreateFlagsqueueFamilyIndex: u32queueCount: u32pQueuePriorities: *const c_floatTrait Implementations
Sourceimpl Clone for VkDeviceQueueCreateInfo
impl Clone for VkDeviceQueueCreateInfo
Sourcefn clone(&self) -> VkDeviceQueueCreateInfo
fn clone(&self) -> VkDeviceQueueCreateInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VkDeviceQueueCreateInfo
impl Debug for VkDeviceQueueCreateInfo
Sourceimpl TypedVulkanStructure for VkDeviceQueueCreateInfo
impl TypedVulkanStructure for VkDeviceQueueCreateInfo
Sourceconst TYPE: VkStructureType = 2i32
const TYPE: VkStructureType = 2i32
sType of this structure
Sourcefn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
fn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
Cast structure ref only if sType matches
Sourceimpl VulkanStructure for VkDeviceQueueCreateInfo
impl VulkanStructure for VkDeviceQueueCreateInfo
Sourcefn as_generic(&self) -> &GenericVulkanStructure
fn as_generic(&self) -> &GenericVulkanStructure
Cast structure ref to generic. This is same as transmute but must be safe.
Sourcefn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
fn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
Cast structure mutable ref to generic. This is same as transmute but must be safe.