#[repr(C)]pub struct VkEventCreateInfo {
pub sType: VkStructureType,
pub pNext: *const c_void,
pub flags: VkEventCreateFlags,
}Fields
sType: VkStructureTypepNext: *const c_voidflags: VkEventCreateFlagsTrait Implementations
Sourceimpl Clone for VkEventCreateInfo
impl Clone for VkEventCreateInfo
Sourcefn clone(&self) -> VkEventCreateInfo
fn clone(&self) -> VkEventCreateInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VkEventCreateInfo
impl Debug for VkEventCreateInfo
Sourceimpl TypedVulkanStructure for VkEventCreateInfo
impl TypedVulkanStructure for VkEventCreateInfo
Sourceconst TYPE: VkStructureType = 10i32
const TYPE: VkStructureType = 10i32
sType of this structure
Sourcefn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
fn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
Cast structure ref only if sType matches
Sourceimpl VulkanStructure for VkEventCreateInfo
impl VulkanStructure for VkEventCreateInfo
Sourcefn as_generic(&self) -> &GenericVulkanStructure
fn as_generic(&self) -> &GenericVulkanStructure
Cast structure ref to generic. This is same as transmute but must be safe.
Sourcefn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
fn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
Cast structure mutable ref to generic. This is same as transmute but must be safe.