#[repr(C)]pub struct VkFenceCreateInfo {
pub sType: VkStructureType,
pub pNext: *const c_void,
pub flags: VkFenceCreateFlags,
}Fields
sType: VkStructureTypepNext: *const c_voidflags: VkFenceCreateFlagsTrait Implementations
Sourceimpl Clone for VkFenceCreateInfo
impl Clone for VkFenceCreateInfo
Sourcefn clone(&self) -> VkFenceCreateInfo
fn clone(&self) -> VkFenceCreateInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VkFenceCreateInfo
impl Debug for VkFenceCreateInfo
Sourceimpl TypedVulkanStructure for VkFenceCreateInfo
impl TypedVulkanStructure for VkFenceCreateInfo
Sourceconst TYPE: VkStructureType = 8i32
const TYPE: VkStructureType = 8i32
sType of this structure
Sourcefn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
fn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
Cast structure ref only if sType matches
Sourceimpl VulkanStructure for VkFenceCreateInfo
impl VulkanStructure for VkFenceCreateInfo
Sourcefn as_generic(&self) -> &GenericVulkanStructure
fn as_generic(&self) -> &GenericVulkanStructure
Cast structure ref to generic. This is same as transmute but must be safe.
Sourcefn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
fn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
Cast structure mutable ref to generic. This is same as transmute but must be safe.