#[repr(C)]pub struct VkFormatProperties2KHR {
pub sType: VkStructureType,
pub pNext: *mut c_void,
pub formatProperties: VkFormatProperties,
}Fields
sType: VkStructureTypepNext: *mut c_voidformatProperties: VkFormatPropertiesTrait Implementations
Sourceimpl Clone for VkFormatProperties2KHR
impl Clone for VkFormatProperties2KHR
Sourcefn clone(&self) -> VkFormatProperties2KHR
fn clone(&self) -> VkFormatProperties2KHR
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VkFormatProperties2KHR
impl Debug for VkFormatProperties2KHR
Sourceimpl TypedVulkanSinkStructure for VkFormatProperties2KHR
impl TypedVulkanSinkStructure for VkFormatProperties2KHR
Sourceconst TYPE: VkStructureType = 1_000_059_002i32
const TYPE: VkStructureType = 1_000_059_002i32
sType constant for this structure.Sourcefn uninit_sink() -> MaybeUninit<Self>
fn uninit_sink() -> MaybeUninit<Self>
Constructs an uninitialized cell for this structure, that is ready to pass the api
Sourcefn try_from_generic(g: &GenericVulkanSinkStructure) -> Option<&Self>
fn try_from_generic(g: &GenericVulkanSinkStructure) -> Option<&Self>
Cast structure ref only if sType matches
Sourceimpl VulkanSinkStructure for VkFormatProperties2KHR
impl VulkanSinkStructure for VkFormatProperties2KHR
Sourcefn as_generic(&self) -> &GenericVulkanSinkStructure
fn as_generic(&self) -> &GenericVulkanSinkStructure
Cast this structure ref to generic one. This is same as transmute but must be safe.
Sourcefn as_generic_mut(&mut self) -> &mut GenericVulkanSinkStructure
fn as_generic_mut(&mut self) -> &mut GenericVulkanSinkStructure
Cast this structure mutable ref to generic one. This is same as transmute but must be safe.