#[repr(C)]pub struct VkFramebufferCreateInfo {
pub sType: VkStructureType,
pub pNext: *const c_void,
pub flags: VkFramebufferCreateFlags,
pub renderPass: VkRenderPass,
pub attachmentCount: u32,
pub pAttachments: *const VkImageView,
pub width: u32,
pub height: u32,
pub layers: u32,
}Fields
sType: VkStructureTypepNext: *const c_voidflags: VkFramebufferCreateFlagsrenderPass: VkRenderPassattachmentCount: u32pAttachments: *const VkImageViewwidth: u32height: u32layers: u32Trait Implementations
Sourceimpl Clone for VkFramebufferCreateInfo
impl Clone for VkFramebufferCreateInfo
Sourcefn clone(&self) -> VkFramebufferCreateInfo
fn clone(&self) -> VkFramebufferCreateInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VkFramebufferCreateInfo
impl Debug for VkFramebufferCreateInfo
Sourceimpl TypedVulkanStructure for VkFramebufferCreateInfo
impl TypedVulkanStructure for VkFramebufferCreateInfo
Sourceconst TYPE: VkStructureType = 37i32
const TYPE: VkStructureType = 37i32
sType of this structure
Sourcefn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
fn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
Cast structure ref only if sType matches
Sourceimpl VulkanStructure for VkFramebufferCreateInfo
impl VulkanStructure for VkFramebufferCreateInfo
Sourcefn as_generic(&self) -> &GenericVulkanStructure
fn as_generic(&self) -> &GenericVulkanStructure
Cast structure ref to generic. This is same as transmute but must be safe.
Sourcefn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
fn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
Cast structure mutable ref to generic. This is same as transmute but must be safe.