#[repr(C)]pub struct VkImageCreateInfo {Show 15 fields
pub sType: VkStructureType,
pub pNext: *const c_void,
pub flags: VkImageCreateFlags,
pub imageType: VkImageType,
pub format: VkFormat,
pub extent: VkExtent3D,
pub mipLevels: u32,
pub arrayLayers: u32,
pub samples: VkSampleCountFlagBits,
pub tiling: VkImageTiling,
pub usage: VkImageUsageFlags,
pub sharingMode: VkSharingMode,
pub queueFamilyIndexCount: u32,
pub pQueueFamilyIndices: *const u32,
pub initialLayout: VkImageLayout,
}Fields
sType: VkStructureTypepNext: *const c_voidflags: VkImageCreateFlagsimageType: VkImageTypeformat: VkFormatextent: VkExtent3DmipLevels: u32arrayLayers: u32samples: VkSampleCountFlagBitstiling: VkImageTilingusage: VkImageUsageFlagssharingMode: VkSharingModequeueFamilyIndexCount: u32pQueueFamilyIndices: *const u32initialLayout: VkImageLayoutTrait Implementations
Sourceimpl AsRef<VkImageCreateInfo> for ImageCreateInfo<'_>
impl AsRef<VkImageCreateInfo> for ImageCreateInfo<'_>
Sourcefn as_ref(&self) -> &VkImageCreateInfo
fn as_ref(&self) -> &VkImageCreateInfo
Converts this type into a shared reference of the (usually inferred) input type.
Sourceimpl Clone for VkImageCreateInfo
impl Clone for VkImageCreateInfo
Sourcefn clone(&self) -> VkImageCreateInfo
fn clone(&self) -> VkImageCreateInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VkImageCreateInfo
impl Debug for VkImageCreateInfo
Sourceimpl TypedVulkanStructure for VkImageCreateInfo
impl TypedVulkanStructure for VkImageCreateInfo
Sourceconst TYPE: VkStructureType = 14i32
const TYPE: VkStructureType = 14i32
sType of this structure
Sourcefn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
fn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
Cast structure ref only if sType matches
Sourceimpl VulkanStructure for VkImageCreateInfo
impl VulkanStructure for VkImageCreateInfo
Sourcefn as_generic(&self) -> &GenericVulkanStructure
fn as_generic(&self) -> &GenericVulkanStructure
Cast structure ref to generic. This is same as transmute but must be safe.
Sourcefn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
fn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
Cast structure mutable ref to generic. This is same as transmute but must be safe.