#[repr(C)]pub struct VkImageMemoryBarrier2KHR {
pub sType: VkStructureType,
pub pNext: *const c_void,
pub srcStageMask: VkPipelineStageFlags2KHR,
pub srcAccessMask: VkAccessFlags2KHR,
pub dstStageMask: VkPipelineStageFlags2KHR,
pub dstAccessMask: VkAccessFlags2KHR,
pub oldLayout: VkImageLayout,
pub newLayout: VkImageLayout,
pub srcQueueFamilyIndex: u32,
pub dstQueueFamilyIndex: u32,
pub image: VkImage,
pub subresourceRange: VkImageSubresourceRange,
}Fields
sType: VkStructureTypepNext: *const c_voidsrcStageMask: VkPipelineStageFlags2KHRsrcAccessMask: VkAccessFlags2KHRdstStageMask: VkPipelineStageFlags2KHRdstAccessMask: VkAccessFlags2KHRoldLayout: VkImageLayoutnewLayout: VkImageLayoutsrcQueueFamilyIndex: u32dstQueueFamilyIndex: u32image: VkImagesubresourceRange: VkImageSubresourceRangeTrait Implementations
Sourceimpl Clone for VkImageMemoryBarrier2KHR
impl Clone for VkImageMemoryBarrier2KHR
Sourcefn clone(&self) -> VkImageMemoryBarrier2KHR
fn clone(&self) -> VkImageMemoryBarrier2KHR
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VkImageMemoryBarrier2KHR
impl Debug for VkImageMemoryBarrier2KHR
Sourceimpl TypedVulkanStructure for VkImageMemoryBarrier2KHR
impl TypedVulkanStructure for VkImageMemoryBarrier2KHR
Sourceconst TYPE: VkStructureType = 1_000_314_002i32
const TYPE: VkStructureType = 1_000_314_002i32
sType of this structure
Sourcefn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
fn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
Cast structure ref only if sType matches
Sourceimpl VulkanStructure for VkImageMemoryBarrier2KHR
impl VulkanStructure for VkImageMemoryBarrier2KHR
Sourcefn as_generic(&self) -> &GenericVulkanStructure
fn as_generic(&self) -> &GenericVulkanStructure
Cast structure ref to generic. This is same as transmute but must be safe.
Sourcefn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
fn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
Cast structure mutable ref to generic. This is same as transmute but must be safe.