#[repr(C)]pub struct VkImageSparseMemoryRequirementsInfo2KHR {
pub sType: VkStructureType,
pub pNext: *const c_void,
pub image: VkImage,
}Fields
sType: VkStructureTypepNext: *const c_voidimage: VkImageTrait Implementations
Sourceimpl Clone for VkImageSparseMemoryRequirementsInfo2KHR
impl Clone for VkImageSparseMemoryRequirementsInfo2KHR
Sourcefn clone(&self) -> VkImageSparseMemoryRequirementsInfo2KHR
fn clone(&self) -> VkImageSparseMemoryRequirementsInfo2KHR
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl TypedVulkanStructure for VkImageSparseMemoryRequirementsInfo2KHR
impl TypedVulkanStructure for VkImageSparseMemoryRequirementsInfo2KHR
Sourceconst TYPE: VkStructureType = 1_000_146_002i32
const TYPE: VkStructureType = 1_000_146_002i32
sType of this structure
Sourcefn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
fn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
Cast structure ref only if sType matches
Sourceimpl VulkanStructure for VkImageSparseMemoryRequirementsInfo2KHR
impl VulkanStructure for VkImageSparseMemoryRequirementsInfo2KHR
Sourcefn as_generic(&self) -> &GenericVulkanStructure
fn as_generic(&self) -> &GenericVulkanStructure
Cast structure ref to generic. This is same as transmute but must be safe.
Sourcefn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
fn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
Cast structure mutable ref to generic. This is same as transmute but must be safe.