#[repr(C)]pub struct VkImageViewCreateInfo {
pub sType: VkStructureType,
pub pNext: *const c_void,
pub flags: VkImageViewCreateFlags,
pub image: VkImage,
pub viewType: VkImageViewType,
pub format: VkFormat,
pub components: VkComponentMapping,
pub subresourceRange: VkImageSubresourceRange,
}Fields
sType: VkStructureTypepNext: *const c_voidflags: VkImageViewCreateFlagsimage: VkImageviewType: VkImageViewTypeformat: VkFormatcomponents: VkComponentMappingsubresourceRange: VkImageSubresourceRangeTrait Implementations
Sourceimpl Clone for VkImageViewCreateInfo
impl Clone for VkImageViewCreateInfo
Sourcefn clone(&self) -> VkImageViewCreateInfo
fn clone(&self) -> VkImageViewCreateInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VkImageViewCreateInfo
impl Debug for VkImageViewCreateInfo
Sourceimpl TypedVulkanStructure for VkImageViewCreateInfo
impl TypedVulkanStructure for VkImageViewCreateInfo
Sourceconst TYPE: VkStructureType = 15i32
const TYPE: VkStructureType = 15i32
sType of this structure
Sourcefn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
fn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
Cast structure ref only if sType matches
Sourceimpl VulkanStructure for VkImageViewCreateInfo
impl VulkanStructure for VkImageViewCreateInfo
Sourcefn as_generic(&self) -> &GenericVulkanStructure
fn as_generic(&self) -> &GenericVulkanStructure
Cast structure ref to generic. This is same as transmute but must be safe.
Sourcefn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
fn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
Cast structure mutable ref to generic. This is same as transmute but must be safe.