#[repr(C)]pub struct VkInstanceCreateInfo {
pub sType: VkStructureType,
pub pNext: *const c_void,
pub flags: VkInstanceCreateFlags,
pub pApplicationInfo: *const VkApplicationInfo,
pub enabledLayerCount: u32,
pub ppEnabledLayerNames: *const *const c_char,
pub enabledExtensionCount: u32,
pub ppEnabledExtensionNames: *const *const c_char,
}Fields
sType: VkStructureTypepNext: *const c_voidflags: VkInstanceCreateFlagspApplicationInfo: *const VkApplicationInfoenabledLayerCount: u32ppEnabledLayerNames: *const *const c_charenabledExtensionCount: u32ppEnabledExtensionNames: *const *const c_charTrait Implementations
Sourceimpl Clone for VkInstanceCreateInfo
impl Clone for VkInstanceCreateInfo
Sourcefn clone(&self) -> VkInstanceCreateInfo
fn clone(&self) -> VkInstanceCreateInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VkInstanceCreateInfo
impl Debug for VkInstanceCreateInfo
Sourceimpl TypedVulkanStructure for VkInstanceCreateInfo
impl TypedVulkanStructure for VkInstanceCreateInfo
Sourceconst TYPE: VkStructureType = 1i32
const TYPE: VkStructureType = 1i32
sType of this structure
Sourcefn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
fn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
Cast structure ref only if sType matches
Sourceimpl VulkanStructure for VkInstanceCreateInfo
impl VulkanStructure for VkInstanceCreateInfo
Sourcefn as_generic(&self) -> &GenericVulkanStructure
fn as_generic(&self) -> &GenericVulkanStructure
Cast structure ref to generic. This is same as transmute but must be safe.
Sourcefn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
fn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
Cast structure mutable ref to generic. This is same as transmute but must be safe.