#[repr(C)]pub struct VkMappedMemoryRange {
pub sType: VkStructureType,
pub pNext: *const c_void,
pub memory: VkDeviceMemory,
pub offset: VkDeviceSize,
pub size: VkDeviceSize,
}Fields
sType: VkStructureTypepNext: *const c_voidmemory: VkDeviceMemoryoffset: VkDeviceSizesize: VkDeviceSizeTrait Implementations
Sourceimpl Clone for VkMappedMemoryRange
impl Clone for VkMappedMemoryRange
Sourcefn clone(&self) -> VkMappedMemoryRange
fn clone(&self) -> VkMappedMemoryRange
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VkMappedMemoryRange
impl Debug for VkMappedMemoryRange
Sourceimpl TypedVulkanStructure for VkMappedMemoryRange
impl TypedVulkanStructure for VkMappedMemoryRange
Sourceconst TYPE: VkStructureType = 6i32
const TYPE: VkStructureType = 6i32
sType of this structure
Sourcefn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
fn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
Cast structure ref only if sType matches
Sourceimpl VulkanStructure for VkMappedMemoryRange
impl VulkanStructure for VkMappedMemoryRange
Sourcefn as_generic(&self) -> &GenericVulkanStructure
fn as_generic(&self) -> &GenericVulkanStructure
Cast structure ref to generic. This is same as transmute but must be safe.
Sourcefn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
fn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
Cast structure mutable ref to generic. This is same as transmute but must be safe.