#[repr(C)]pub struct VkMemoryAllocateInfo {
pub sType: VkStructureType,
pub pNext: *const c_void,
pub allocationSize: VkDeviceSize,
pub memoryTypeIndex: u32,
}Fields
sType: VkStructureTypepNext: *const c_voidallocationSize: VkDeviceSizememoryTypeIndex: u32Trait Implementations
Sourceimpl Clone for VkMemoryAllocateInfo
impl Clone for VkMemoryAllocateInfo
Sourcefn clone(&self) -> VkMemoryAllocateInfo
fn clone(&self) -> VkMemoryAllocateInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VkMemoryAllocateInfo
impl Debug for VkMemoryAllocateInfo
Sourceimpl TypedVulkanStructure for VkMemoryAllocateInfo
impl TypedVulkanStructure for VkMemoryAllocateInfo
Sourceconst TYPE: VkStructureType = 5i32
const TYPE: VkStructureType = 5i32
sType of this structure
Sourcefn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
fn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
Cast structure ref only if sType matches
Sourceimpl VulkanStructure for VkMemoryAllocateInfo
impl VulkanStructure for VkMemoryAllocateInfo
Sourcefn as_generic(&self) -> &GenericVulkanStructure
fn as_generic(&self) -> &GenericVulkanStructure
Cast structure ref to generic. This is same as transmute but must be safe.
Sourcefn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
fn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
Cast structure mutable ref to generic. This is same as transmute but must be safe.