#[repr(C)]pub struct VkMemoryBarrier {
pub sType: VkStructureType,
pub pNext: *const c_void,
pub srcAccessMask: VkAccessFlags,
pub dstAccessMask: VkAccessFlags,
}Fields
sType: VkStructureTypepNext: *const c_voidsrcAccessMask: VkAccessFlagsdstAccessMask: VkAccessFlagsTrait Implementations
Sourceimpl Clone for VkMemoryBarrier
impl Clone for VkMemoryBarrier
Sourcefn clone(&self) -> VkMemoryBarrier
fn clone(&self) -> VkMemoryBarrier
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VkMemoryBarrier
impl Debug for VkMemoryBarrier
Sourceimpl TypedVulkanStructure for VkMemoryBarrier
impl TypedVulkanStructure for VkMemoryBarrier
Sourceconst TYPE: VkStructureType = 46i32
const TYPE: VkStructureType = 46i32
sType of this structure
Sourcefn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
fn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
Cast structure ref only if sType matches
Sourceimpl VulkanStructure for VkMemoryBarrier
impl VulkanStructure for VkMemoryBarrier
Sourcefn as_generic(&self) -> &GenericVulkanStructure
fn as_generic(&self) -> &GenericVulkanStructure
Cast structure ref to generic. This is same as transmute but must be safe.
Sourcefn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
fn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
Cast structure mutable ref to generic. This is same as transmute but must be safe.