#[repr(C)]pub struct VkMemoryBarrier2KHR {
pub sType: VkStructureType,
pub pNext: *const c_void,
pub srcStageMask: VkPipelineStageFlags2KHR,
pub srcAccessMask: VkAccessFlags2KHR,
pub dstStageMask: VkPipelineStageFlags2KHR,
pub dstAccessMask: VkAccessFlags2KHR,
}Fields
sType: VkStructureTypepNext: *const c_voidsrcStageMask: VkPipelineStageFlags2KHRsrcAccessMask: VkAccessFlags2KHRdstStageMask: VkPipelineStageFlags2KHRdstAccessMask: VkAccessFlags2KHRTrait Implementations
Sourceimpl Clone for VkMemoryBarrier2KHR
impl Clone for VkMemoryBarrier2KHR
Sourcefn clone(&self) -> VkMemoryBarrier2KHR
fn clone(&self) -> VkMemoryBarrier2KHR
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VkMemoryBarrier2KHR
impl Debug for VkMemoryBarrier2KHR
Sourceimpl TypedVulkanStructure for VkMemoryBarrier2KHR
impl TypedVulkanStructure for VkMemoryBarrier2KHR
Sourceconst TYPE: VkStructureType = 1_000_314_000i32
const TYPE: VkStructureType = 1_000_314_000i32
sType of this structure
Sourcefn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
fn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
Cast structure ref only if sType matches
Sourceimpl VulkanStructure for VkMemoryBarrier2KHR
impl VulkanStructure for VkMemoryBarrier2KHR
Sourcefn as_generic(&self) -> &GenericVulkanStructure
fn as_generic(&self) -> &GenericVulkanStructure
Cast structure ref to generic. This is same as transmute but must be safe.
Sourcefn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
fn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
Cast structure mutable ref to generic. This is same as transmute but must be safe.