#[repr(C)]pub struct VkMemoryDedicatedAllocateInfoKHR {
pub sType: VkStructureType,
pub pNext: *const c_void,
pub image: VkImage,
pub buffer: VkBuffer,
}Fields
sType: VkStructureTypepNext: *const c_voidimage: VkImagebuffer: VkBufferTrait Implementations
Sourceimpl Clone for VkMemoryDedicatedAllocateInfoKHR
impl Clone for VkMemoryDedicatedAllocateInfoKHR
Sourcefn clone(&self) -> VkMemoryDedicatedAllocateInfoKHR
fn clone(&self) -> VkMemoryDedicatedAllocateInfoKHR
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl TypedVulkanStructure for VkMemoryDedicatedAllocateInfoKHR
impl TypedVulkanStructure for VkMemoryDedicatedAllocateInfoKHR
Sourceconst TYPE: VkStructureType = 1_000_127_001i32
const TYPE: VkStructureType = 1_000_127_001i32
sType of this structure
Sourcefn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
fn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
Cast structure ref only if sType matches
Sourceimpl VulkanStructure for VkMemoryDedicatedAllocateInfoKHR
impl VulkanStructure for VkMemoryDedicatedAllocateInfoKHR
Sourcefn as_generic(&self) -> &GenericVulkanStructure
fn as_generic(&self) -> &GenericVulkanStructure
Cast structure ref to generic. This is same as transmute but must be safe.
Sourcefn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
fn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
Cast structure mutable ref to generic. This is same as transmute but must be safe.