#[repr(C)]pub struct VkMemoryDedicatedRequirementsKHR {
pub sType: VkStructureType,
pub pNext: *mut c_void,
pub prefersDedicatedAllocation: VkBool32,
pub requiresDedicatedAllocation: VkBool32,
}Fields
sType: VkStructureTypepNext: *mut c_voidprefersDedicatedAllocation: VkBool32requiresDedicatedAllocation: VkBool32Trait Implementations
Sourceimpl Clone for VkMemoryDedicatedRequirementsKHR
impl Clone for VkMemoryDedicatedRequirementsKHR
Sourcefn clone(&self) -> VkMemoryDedicatedRequirementsKHR
fn clone(&self) -> VkMemoryDedicatedRequirementsKHR
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl TypedVulkanSinkStructure for VkMemoryDedicatedRequirementsKHR
impl TypedVulkanSinkStructure for VkMemoryDedicatedRequirementsKHR
Sourceconst TYPE: VkStructureType = 1_000_127_000i32
const TYPE: VkStructureType = 1_000_127_000i32
sType constant for this structure.Sourcefn uninit_sink() -> MaybeUninit<Self>
fn uninit_sink() -> MaybeUninit<Self>
Constructs an uninitialized cell for this structure, that is ready to pass the api
Sourcefn try_from_generic(g: &GenericVulkanSinkStructure) -> Option<&Self>
fn try_from_generic(g: &GenericVulkanSinkStructure) -> Option<&Self>
Cast structure ref only if sType matches
Sourceimpl VulkanSinkStructure for VkMemoryDedicatedRequirementsKHR
impl VulkanSinkStructure for VkMemoryDedicatedRequirementsKHR
Sourcefn as_generic(&self) -> &GenericVulkanSinkStructure
fn as_generic(&self) -> &GenericVulkanSinkStructure
Cast this structure ref to generic one. This is same as transmute but must be safe.
Sourcefn as_generic_mut(&mut self) -> &mut GenericVulkanSinkStructure
fn as_generic_mut(&mut self) -> &mut GenericVulkanSinkStructure
Cast this structure mutable ref to generic one. This is same as transmute but must be safe.