#[repr(C)]pub struct VkMemoryRequirements2KHR {
pub sType: VkStructureType,
pub pNext: *mut c_void,
pub memoryRequirements: VkMemoryRequirements,
}Fields
sType: VkStructureTypepNext: *mut c_voidmemoryRequirements: VkMemoryRequirementsTrait Implementations
Sourceimpl Clone for VkMemoryRequirements2KHR
impl Clone for VkMemoryRequirements2KHR
Sourcefn clone(&self) -> VkMemoryRequirements2KHR
fn clone(&self) -> VkMemoryRequirements2KHR
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VkMemoryRequirements2KHR
impl Debug for VkMemoryRequirements2KHR
Sourceimpl TypedVulkanSinkStructure for VkMemoryRequirements2KHR
impl TypedVulkanSinkStructure for VkMemoryRequirements2KHR
Sourceconst TYPE: VkStructureType = 1_000_146_003i32
const TYPE: VkStructureType = 1_000_146_003i32
sType constant for this structure.Sourcefn uninit_sink() -> MaybeUninit<Self>
fn uninit_sink() -> MaybeUninit<Self>
Constructs an uninitialized cell for this structure, that is ready to pass the api
Sourcefn try_from_generic(g: &GenericVulkanSinkStructure) -> Option<&Self>
fn try_from_generic(g: &GenericVulkanSinkStructure) -> Option<&Self>
Cast structure ref only if sType matches
Sourceimpl VulkanSinkStructure for VkMemoryRequirements2KHR
impl VulkanSinkStructure for VkMemoryRequirements2KHR
Sourcefn as_generic(&self) -> &GenericVulkanSinkStructure
fn as_generic(&self) -> &GenericVulkanSinkStructure
Cast this structure ref to generic one. This is same as transmute but must be safe.
Sourcefn as_generic_mut(&mut self) -> &mut GenericVulkanSinkStructure
fn as_generic_mut(&mut self) -> &mut GenericVulkanSinkStructure
Cast this structure mutable ref to generic one. This is same as transmute but must be safe.