#[repr(C)]pub struct VkPhysicalDeviceFeatures2KHR {
pub sType: VkStructureType,
pub pNext: *mut c_void,
pub features: VkPhysicalDeviceFeatures,
}Fields
sType: VkStructureTypepNext: *mut c_voidfeatures: VkPhysicalDeviceFeaturesTrait Implementations
Sourceimpl Clone for VkPhysicalDeviceFeatures2KHR
impl Clone for VkPhysicalDeviceFeatures2KHR
Sourcefn clone(&self) -> VkPhysicalDeviceFeatures2KHR
fn clone(&self) -> VkPhysicalDeviceFeatures2KHR
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VkPhysicalDeviceFeatures2KHR
impl Debug for VkPhysicalDeviceFeatures2KHR
Sourceimpl TypedVulkanSinkStructure for VkPhysicalDeviceFeatures2KHR
impl TypedVulkanSinkStructure for VkPhysicalDeviceFeatures2KHR
Sourceconst TYPE: VkStructureType = 1_000_059_000i32
const TYPE: VkStructureType = 1_000_059_000i32
sType constant for this structure.Sourcefn uninit_sink() -> MaybeUninit<Self>
fn uninit_sink() -> MaybeUninit<Self>
Constructs an uninitialized cell for this structure, that is ready to pass the api
Sourcefn try_from_generic(g: &GenericVulkanSinkStructure) -> Option<&Self>
fn try_from_generic(g: &GenericVulkanSinkStructure) -> Option<&Self>
Cast structure ref only if sType matches
Sourceimpl TypedVulkanStructure for VkPhysicalDeviceFeatures2KHR
impl TypedVulkanStructure for VkPhysicalDeviceFeatures2KHR
Sourceconst TYPE: VkStructureType = 1_000_059_000i32
const TYPE: VkStructureType = 1_000_059_000i32
sType of this structure
Sourcefn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
fn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
Cast structure ref only if sType matches
Sourceimpl VulkanSinkStructure for VkPhysicalDeviceFeatures2KHR
impl VulkanSinkStructure for VkPhysicalDeviceFeatures2KHR
Sourcefn as_generic(&self) -> &GenericVulkanSinkStructure
fn as_generic(&self) -> &GenericVulkanSinkStructure
Cast this structure ref to generic one. This is same as transmute but must be safe.
Sourcefn as_generic_mut(&mut self) -> &mut GenericVulkanSinkStructure
fn as_generic_mut(&mut self) -> &mut GenericVulkanSinkStructure
Cast this structure mutable ref to generic one. This is same as transmute but must be safe.
Sourceimpl VulkanStructure for VkPhysicalDeviceFeatures2KHR
impl VulkanStructure for VkPhysicalDeviceFeatures2KHR
Sourcefn as_generic(&self) -> &GenericVulkanStructure
fn as_generic(&self) -> &GenericVulkanStructure
Cast structure ref to generic. This is same as transmute but must be safe.
Sourcefn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
fn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
Cast structure mutable ref to generic. This is same as transmute but must be safe.