#[repr(C)]pub struct VkPhysicalDeviceProperties2KHR {
pub sType: VkStructureType,
pub pNext: *mut c_void,
pub properties: VkPhysicalDeviceProperties,
}Fields
sType: VkStructureTypepNext: *mut c_voidproperties: VkPhysicalDevicePropertiesTrait Implementations
Sourceimpl Clone for VkPhysicalDeviceProperties2KHR
impl Clone for VkPhysicalDeviceProperties2KHR
Sourcefn clone(&self) -> VkPhysicalDeviceProperties2KHR
fn clone(&self) -> VkPhysicalDeviceProperties2KHR
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl TypedVulkanSinkStructure for VkPhysicalDeviceProperties2KHR
impl TypedVulkanSinkStructure for VkPhysicalDeviceProperties2KHR
Sourceconst TYPE: VkStructureType = 1_000_059_001i32
const TYPE: VkStructureType = 1_000_059_001i32
sType constant for this structure.Sourcefn uninit_sink() -> MaybeUninit<Self>
fn uninit_sink() -> MaybeUninit<Self>
Constructs an uninitialized cell for this structure, that is ready to pass the api
Sourcefn try_from_generic(g: &GenericVulkanSinkStructure) -> Option<&Self>
fn try_from_generic(g: &GenericVulkanSinkStructure) -> Option<&Self>
Cast structure ref only if sType matches
Sourceimpl VulkanSinkStructure for VkPhysicalDeviceProperties2KHR
impl VulkanSinkStructure for VkPhysicalDeviceProperties2KHR
Sourcefn as_generic(&self) -> &GenericVulkanSinkStructure
fn as_generic(&self) -> &GenericVulkanSinkStructure
Cast this structure ref to generic one. This is same as transmute but must be safe.
Sourcefn as_generic_mut(&mut self) -> &mut GenericVulkanSinkStructure
fn as_generic_mut(&mut self) -> &mut GenericVulkanSinkStructure
Cast this structure mutable ref to generic one. This is same as transmute but must be safe.