#[repr(C)]pub struct VkPhysicalDeviceSparseImageFormatInfo2KHR {
pub sType: VkStructureType,
pub pNext: *const c_void,
pub format: VkFormat,
pub type: VkImageType,
pub samples: VkSampleCountFlagBits,
pub usage: VkImageUsageFlags,
pub tiling: VkImageTiling,
}Fields
sType: VkStructureTypepNext: *const c_voidformat: VkFormattype: VkImageTypesamples: VkSampleCountFlagBitsusage: VkImageUsageFlagstiling: VkImageTilingTrait Implementations
Sourceimpl Clone for VkPhysicalDeviceSparseImageFormatInfo2KHR
impl Clone for VkPhysicalDeviceSparseImageFormatInfo2KHR
Sourcefn clone(&self) -> VkPhysicalDeviceSparseImageFormatInfo2KHR
fn clone(&self) -> VkPhysicalDeviceSparseImageFormatInfo2KHR
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl TypedVulkanStructure for VkPhysicalDeviceSparseImageFormatInfo2KHR
impl TypedVulkanStructure for VkPhysicalDeviceSparseImageFormatInfo2KHR
Sourceconst TYPE: VkStructureType = 1_000_059_008i32
const TYPE: VkStructureType = 1_000_059_008i32
sType of this structure
Sourcefn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
fn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
Cast structure ref only if sType matches
Sourceimpl VulkanStructure for VkPhysicalDeviceSparseImageFormatInfo2KHR
impl VulkanStructure for VkPhysicalDeviceSparseImageFormatInfo2KHR
Sourcefn as_generic(&self) -> &GenericVulkanStructure
fn as_generic(&self) -> &GenericVulkanStructure
Cast structure ref to generic. This is same as transmute but must be safe.
Sourcefn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
fn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
Cast structure mutable ref to generic. This is same as transmute but must be safe.