#[repr(C)]pub struct VkPhysicalDeviceSynchronization2FeaturesKHR {
pub sType: VkStructureType,
pub pNext: *mut c_void,
pub synchronization2: VkBool32,
}Fields
sType: VkStructureTypepNext: *mut c_voidsynchronization2: VkBool32Trait Implementations
Sourceimpl Clone for VkPhysicalDeviceSynchronization2FeaturesKHR
impl Clone for VkPhysicalDeviceSynchronization2FeaturesKHR
Sourcefn clone(&self) -> VkPhysicalDeviceSynchronization2FeaturesKHR
fn clone(&self) -> VkPhysicalDeviceSynchronization2FeaturesKHR
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl TypedVulkanSinkStructure for VkPhysicalDeviceSynchronization2FeaturesKHR
impl TypedVulkanSinkStructure for VkPhysicalDeviceSynchronization2FeaturesKHR
Sourceconst TYPE: VkStructureType = 1_000_314_007i32
const TYPE: VkStructureType = 1_000_314_007i32
sType constant for this structure.Sourcefn uninit_sink() -> MaybeUninit<Self>
fn uninit_sink() -> MaybeUninit<Self>
Constructs an uninitialized cell for this structure, that is ready to pass the api
Sourcefn try_from_generic(g: &GenericVulkanSinkStructure) -> Option<&Self>
fn try_from_generic(g: &GenericVulkanSinkStructure) -> Option<&Self>
Cast structure ref only if sType matches
Sourceimpl TypedVulkanStructure for VkPhysicalDeviceSynchronization2FeaturesKHR
impl TypedVulkanStructure for VkPhysicalDeviceSynchronization2FeaturesKHR
Sourceconst TYPE: VkStructureType = 1_000_314_007i32
const TYPE: VkStructureType = 1_000_314_007i32
sType of this structure
Sourcefn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
fn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
Cast structure ref only if sType matches
Sourceimpl VulkanSinkStructure for VkPhysicalDeviceSynchronization2FeaturesKHR
impl VulkanSinkStructure for VkPhysicalDeviceSynchronization2FeaturesKHR
Sourcefn as_generic(&self) -> &GenericVulkanSinkStructure
fn as_generic(&self) -> &GenericVulkanSinkStructure
Cast this structure ref to generic one. This is same as transmute but must be safe.
Sourcefn as_generic_mut(&mut self) -> &mut GenericVulkanSinkStructure
fn as_generic_mut(&mut self) -> &mut GenericVulkanSinkStructure
Cast this structure mutable ref to generic one. This is same as transmute but must be safe.
Sourceimpl VulkanStructure for VkPhysicalDeviceSynchronization2FeaturesKHR
impl VulkanStructure for VkPhysicalDeviceSynchronization2FeaturesKHR
Sourcefn as_generic(&self) -> &GenericVulkanStructure
fn as_generic(&self) -> &GenericVulkanStructure
Cast structure ref to generic. This is same as transmute but must be safe.
Sourcefn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
fn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
Cast structure mutable ref to generic. This is same as transmute but must be safe.