#[repr(C)]pub struct VkPipelineCacheCreateInfo {
pub sType: VkStructureType,
pub pNext: *const c_void,
pub flags: VkPipelineCacheCreateFlags,
pub initialDataSize: usize,
pub pInitialData: *const c_void,
}Fields
sType: VkStructureTypepNext: *const c_voidflags: VkPipelineCacheCreateFlagsinitialDataSize: usizepInitialData: *const c_voidTrait Implementations
Sourceimpl Clone for VkPipelineCacheCreateInfo
impl Clone for VkPipelineCacheCreateInfo
Sourcefn clone(&self) -> VkPipelineCacheCreateInfo
fn clone(&self) -> VkPipelineCacheCreateInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VkPipelineCacheCreateInfo
impl Debug for VkPipelineCacheCreateInfo
Sourceimpl TypedVulkanStructure for VkPipelineCacheCreateInfo
impl TypedVulkanStructure for VkPipelineCacheCreateInfo
Sourceconst TYPE: VkStructureType = 17i32
const TYPE: VkStructureType = 17i32
sType of this structure
Sourcefn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
fn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
Cast structure ref only if sType matches
Sourceimpl VulkanStructure for VkPipelineCacheCreateInfo
impl VulkanStructure for VkPipelineCacheCreateInfo
Sourcefn as_generic(&self) -> &GenericVulkanStructure
fn as_generic(&self) -> &GenericVulkanStructure
Cast structure ref to generic. This is same as transmute but must be safe.
Sourcefn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
fn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
Cast structure mutable ref to generic. This is same as transmute but must be safe.