#[repr(C)]pub struct VkPipelineDepthStencilStateCreateInfo {
pub sType: VkStructureType,
pub pNext: *const c_void,
pub flags: VkPipelineDepthStencilStateCreateFlags,
pub depthTestEnable: VkBool32,
pub depthWriteEnable: VkBool32,
pub depthCompareOp: VkCompareOp,
pub depthBoundsTestEnable: VkBool32,
pub stencilTestEnable: VkBool32,
pub front: VkStencilOpState,
pub back: VkStencilOpState,
pub minDepthBounds: c_float,
pub maxDepthBounds: c_float,
}Fields
sType: VkStructureTypepNext: *const c_voidflags: VkPipelineDepthStencilStateCreateFlagsdepthTestEnable: VkBool32depthWriteEnable: VkBool32depthCompareOp: VkCompareOpdepthBoundsTestEnable: VkBool32stencilTestEnable: VkBool32front: VkStencilOpStateback: VkStencilOpStateminDepthBounds: c_floatmaxDepthBounds: c_floatTrait Implementations
Sourceimpl Clone for VkPipelineDepthStencilStateCreateInfo
impl Clone for VkPipelineDepthStencilStateCreateInfo
Sourcefn clone(&self) -> VkPipelineDepthStencilStateCreateInfo
fn clone(&self) -> VkPipelineDepthStencilStateCreateInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl TypedVulkanStructure for VkPipelineDepthStencilStateCreateInfo
impl TypedVulkanStructure for VkPipelineDepthStencilStateCreateInfo
Sourceconst TYPE: VkStructureType = 25i32
const TYPE: VkStructureType = 25i32
sType of this structure
Sourcefn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
fn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
Cast structure ref only if sType matches
Sourceimpl VulkanStructure for VkPipelineDepthStencilStateCreateInfo
impl VulkanStructure for VkPipelineDepthStencilStateCreateInfo
Sourcefn as_generic(&self) -> &GenericVulkanStructure
fn as_generic(&self) -> &GenericVulkanStructure
Cast structure ref to generic. This is same as transmute but must be safe.
Sourcefn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
fn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
Cast structure mutable ref to generic. This is same as transmute but must be safe.