#[repr(C)]pub struct VkPipelineDynamicStateCreateInfo {
pub sType: VkStructureType,
pub pNext: *const c_void,
pub flags: VkPipelineDynamicStateCreateFlags,
pub dynamicStateCount: u32,
pub pDynamicStates: *const VkDynamicState,
}Fields
sType: VkStructureTypepNext: *const c_voidflags: VkPipelineDynamicStateCreateFlagsdynamicStateCount: u32pDynamicStates: *const VkDynamicStateTrait Implementations
Sourceimpl Clone for VkPipelineDynamicStateCreateInfo
impl Clone for VkPipelineDynamicStateCreateInfo
Sourcefn clone(&self) -> VkPipelineDynamicStateCreateInfo
fn clone(&self) -> VkPipelineDynamicStateCreateInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl TypedVulkanStructure for VkPipelineDynamicStateCreateInfo
impl TypedVulkanStructure for VkPipelineDynamicStateCreateInfo
Sourceconst TYPE: VkStructureType = 27i32
const TYPE: VkStructureType = 27i32
sType of this structure
Sourcefn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
fn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
Cast structure ref only if sType matches
Sourceimpl VulkanStructure for VkPipelineDynamicStateCreateInfo
impl VulkanStructure for VkPipelineDynamicStateCreateInfo
Sourcefn as_generic(&self) -> &GenericVulkanStructure
fn as_generic(&self) -> &GenericVulkanStructure
Cast structure ref to generic. This is same as transmute but must be safe.
Sourcefn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
fn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
Cast structure mutable ref to generic. This is same as transmute but must be safe.