#[repr(C)]pub struct VkPipelineInputAssemblyStateCreateInfo {
pub sType: VkStructureType,
pub pNext: *const c_void,
pub flags: VkPipelineInputAssemblyStateCreateFlags,
pub topology: VkPrimitiveTopology,
pub primitiveRestartEnable: VkBool32,
}Fields
sType: VkStructureTypepNext: *const c_voidflags: VkPipelineInputAssemblyStateCreateFlagstopology: VkPrimitiveTopologyprimitiveRestartEnable: VkBool32Trait Implementations
Sourceimpl Clone for VkPipelineInputAssemblyStateCreateInfo
impl Clone for VkPipelineInputAssemblyStateCreateInfo
Sourcefn clone(&self) -> VkPipelineInputAssemblyStateCreateInfo
fn clone(&self) -> VkPipelineInputAssemblyStateCreateInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl TypedVulkanStructure for VkPipelineInputAssemblyStateCreateInfo
impl TypedVulkanStructure for VkPipelineInputAssemblyStateCreateInfo
Sourceconst TYPE: VkStructureType = 20i32
const TYPE: VkStructureType = 20i32
sType of this structure
Sourcefn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
fn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
Cast structure ref only if sType matches
Sourceimpl VulkanStructure for VkPipelineInputAssemblyStateCreateInfo
impl VulkanStructure for VkPipelineInputAssemblyStateCreateInfo
Sourcefn as_generic(&self) -> &GenericVulkanStructure
fn as_generic(&self) -> &GenericVulkanStructure
Cast structure ref to generic. This is same as transmute but must be safe.
Sourcefn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
fn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
Cast structure mutable ref to generic. This is same as transmute but must be safe.