#[repr(C)]pub struct VkPipelineLayoutCreateInfo {
pub sType: VkStructureType,
pub pNext: *const c_void,
pub flags: VkPipelineLayoutCreateFlags,
pub setLayoutCount: u32,
pub pSetLayouts: *const VkDescriptorSetLayout,
pub pushConstantRangeCount: u32,
pub pPushConstantRanges: *const VkPushConstantRange,
}Fields
sType: VkStructureTypepNext: *const c_voidflags: VkPipelineLayoutCreateFlagssetLayoutCount: u32pSetLayouts: *const VkDescriptorSetLayoutpushConstantRangeCount: u32pPushConstantRanges: *const VkPushConstantRangeTrait Implementations
Sourceimpl Clone for VkPipelineLayoutCreateInfo
impl Clone for VkPipelineLayoutCreateInfo
Sourcefn clone(&self) -> VkPipelineLayoutCreateInfo
fn clone(&self) -> VkPipelineLayoutCreateInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VkPipelineLayoutCreateInfo
impl Debug for VkPipelineLayoutCreateInfo
Sourceimpl TypedVulkanStructure for VkPipelineLayoutCreateInfo
impl TypedVulkanStructure for VkPipelineLayoutCreateInfo
Sourceconst TYPE: VkStructureType = 30i32
const TYPE: VkStructureType = 30i32
sType of this structure
Sourcefn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
fn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
Cast structure ref only if sType matches
Sourceimpl VulkanStructure for VkPipelineLayoutCreateInfo
impl VulkanStructure for VkPipelineLayoutCreateInfo
Sourcefn as_generic(&self) -> &GenericVulkanStructure
fn as_generic(&self) -> &GenericVulkanStructure
Cast structure ref to generic. This is same as transmute but must be safe.
Sourcefn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
fn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
Cast structure mutable ref to generic. This is same as transmute but must be safe.