#[repr(C)]pub struct VkPipelineShaderStageCreateInfo {
pub sType: VkStructureType,
pub pNext: *const c_void,
pub flags: VkPipelineShaderStageCreateFlags,
pub stage: VkShaderStageFlagBits,
pub module: VkShaderModule,
pub pName: *const c_char,
pub pSpecializationInfo: *const VkSpecializationInfo,
}Fields
sType: VkStructureTypepNext: *const c_voidflags: VkPipelineShaderStageCreateFlagsstage: VkShaderStageFlagBitsmodule: VkShaderModulepName: *const c_charpSpecializationInfo: *const VkSpecializationInfoTrait Implementations
Sourceimpl Clone for VkPipelineShaderStageCreateInfo
impl Clone for VkPipelineShaderStageCreateInfo
Sourcefn clone(&self) -> VkPipelineShaderStageCreateInfo
fn clone(&self) -> VkPipelineShaderStageCreateInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl TypedVulkanStructure for VkPipelineShaderStageCreateInfo
impl TypedVulkanStructure for VkPipelineShaderStageCreateInfo
Sourceconst TYPE: VkStructureType = 18i32
const TYPE: VkStructureType = 18i32
sType of this structure
Sourcefn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
fn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
Cast structure ref only if sType matches
Sourceimpl VulkanStructure for VkPipelineShaderStageCreateInfo
impl VulkanStructure for VkPipelineShaderStageCreateInfo
Sourcefn as_generic(&self) -> &GenericVulkanStructure
fn as_generic(&self) -> &GenericVulkanStructure
Cast structure ref to generic. This is same as transmute but must be safe.
Sourcefn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
fn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
Cast structure mutable ref to generic. This is same as transmute but must be safe.