#[repr(C)]pub struct VkPipelineTessellationStateCreateInfo {
pub sType: VkStructureType,
pub pNext: *const c_void,
pub flags: VkPipelineTessellationStateCreateFlags,
pub patchControlPoints: u32,
}Fields
sType: VkStructureTypepNext: *const c_voidflags: VkPipelineTessellationStateCreateFlagspatchControlPoints: u32Trait Implementations
Sourceimpl Clone for VkPipelineTessellationStateCreateInfo
impl Clone for VkPipelineTessellationStateCreateInfo
Sourcefn clone(&self) -> VkPipelineTessellationStateCreateInfo
fn clone(&self) -> VkPipelineTessellationStateCreateInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl TypedVulkanStructure for VkPipelineTessellationStateCreateInfo
impl TypedVulkanStructure for VkPipelineTessellationStateCreateInfo
Sourceconst TYPE: VkStructureType = 21i32
const TYPE: VkStructureType = 21i32
sType of this structure
Sourcefn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
fn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
Cast structure ref only if sType matches
Sourceimpl VulkanStructure for VkPipelineTessellationStateCreateInfo
impl VulkanStructure for VkPipelineTessellationStateCreateInfo
Sourcefn as_generic(&self) -> &GenericVulkanStructure
fn as_generic(&self) -> &GenericVulkanStructure
Cast structure ref to generic. This is same as transmute but must be safe.
Sourcefn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
fn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
Cast structure mutable ref to generic. This is same as transmute but must be safe.