#[repr(C)]pub struct VkPipelineViewportStateCreateInfo {
pub sType: VkStructureType,
pub pNext: *const c_void,
pub flags: VkPipelineViewportStateCreateFlags,
pub viewportCount: u32,
pub pViewports: *const VkViewport,
pub scissorCount: u32,
pub pScissors: *const VkRect2D,
}Fields
sType: VkStructureTypepNext: *const c_voidflags: VkPipelineViewportStateCreateFlagsviewportCount: u32pViewports: *const VkViewportscissorCount: u32pScissors: *const VkRect2DTrait Implementations
Sourceimpl Clone for VkPipelineViewportStateCreateInfo
impl Clone for VkPipelineViewportStateCreateInfo
Sourcefn clone(&self) -> VkPipelineViewportStateCreateInfo
fn clone(&self) -> VkPipelineViewportStateCreateInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl TypedVulkanStructure for VkPipelineViewportStateCreateInfo
impl TypedVulkanStructure for VkPipelineViewportStateCreateInfo
Sourceconst TYPE: VkStructureType = 22i32
const TYPE: VkStructureType = 22i32
sType of this structure
Sourcefn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
fn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
Cast structure ref only if sType matches
Sourceimpl VulkanStructure for VkPipelineViewportStateCreateInfo
impl VulkanStructure for VkPipelineViewportStateCreateInfo
Sourcefn as_generic(&self) -> &GenericVulkanStructure
fn as_generic(&self) -> &GenericVulkanStructure
Cast structure ref to generic. This is same as transmute but must be safe.
Sourcefn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
fn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
Cast structure mutable ref to generic. This is same as transmute but must be safe.