#[repr(C)]pub struct VkPresentInfoKHR {
pub sType: VkStructureType,
pub pNext: *const c_void,
pub waitSemaphoreCount: u32,
pub pWaitSemaphores: *const VkSemaphore,
pub swapchainCount: u32,
pub pSwapchains: *const VkSwapchainKHR,
pub pImageIndices: *const u32,
pub pResults: *mut VkResult,
}Fields
sType: VkStructureTypepNext: *const c_voidwaitSemaphoreCount: u32pWaitSemaphores: *const VkSemaphoreswapchainCount: u32pSwapchains: *const VkSwapchainKHRpImageIndices: *const u32pResults: *mut VkResultTrait Implementations
Sourceimpl Clone for VkPresentInfoKHR
impl Clone for VkPresentInfoKHR
Sourcefn clone(&self) -> VkPresentInfoKHR
fn clone(&self) -> VkPresentInfoKHR
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VkPresentInfoKHR
impl Debug for VkPresentInfoKHR
Sourceimpl TypedVulkanStructure for VkPresentInfoKHR
impl TypedVulkanStructure for VkPresentInfoKHR
Sourceconst TYPE: VkStructureType = 1_000_001_001i32
const TYPE: VkStructureType = 1_000_001_001i32
sType of this structure
Sourcefn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
fn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
Cast structure ref only if sType matches
Sourceimpl VulkanStructure for VkPresentInfoKHR
impl VulkanStructure for VkPresentInfoKHR
Sourcefn as_generic(&self) -> &GenericVulkanStructure
fn as_generic(&self) -> &GenericVulkanStructure
Cast structure ref to generic. This is same as transmute but must be safe.
Sourcefn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
fn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
Cast structure mutable ref to generic. This is same as transmute but must be safe.