#[repr(C)]pub struct VkQueryPoolCreateInfo {
pub sType: VkStructureType,
pub pNext: *const c_void,
pub flags: VkQueryPoolCreateFlags,
pub queryType: VkQueryType,
pub queryCount: u32,
pub pipelineStatistics: VkQueryPipelineStatisticFlags,
}Fields
sType: VkStructureTypepNext: *const c_voidflags: VkQueryPoolCreateFlagsqueryType: VkQueryTypequeryCount: u32pipelineStatistics: VkQueryPipelineStatisticFlagsTrait Implementations
Sourceimpl Clone for VkQueryPoolCreateInfo
impl Clone for VkQueryPoolCreateInfo
Sourcefn clone(&self) -> VkQueryPoolCreateInfo
fn clone(&self) -> VkQueryPoolCreateInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VkQueryPoolCreateInfo
impl Debug for VkQueryPoolCreateInfo
Sourceimpl TypedVulkanStructure for VkQueryPoolCreateInfo
impl TypedVulkanStructure for VkQueryPoolCreateInfo
Sourceconst TYPE: VkStructureType = 11i32
const TYPE: VkStructureType = 11i32
sType of this structure
Sourcefn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
fn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
Cast structure ref only if sType matches
Sourceimpl VulkanStructure for VkQueryPoolCreateInfo
impl VulkanStructure for VkQueryPoolCreateInfo
Sourcefn as_generic(&self) -> &GenericVulkanStructure
fn as_generic(&self) -> &GenericVulkanStructure
Cast structure ref to generic. This is same as transmute but must be safe.
Sourcefn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
fn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
Cast structure mutable ref to generic. This is same as transmute but must be safe.