#[repr(C)]pub struct VkQueueFamilyProperties2KHR {
pub sType: VkStructureType,
pub pNext: *mut c_void,
pub queueFamilyProperties: VkQueueFamilyProperties,
}Fields
sType: VkStructureTypepNext: *mut c_voidqueueFamilyProperties: VkQueueFamilyPropertiesTrait Implementations
Sourceimpl Clone for VkQueueFamilyProperties2KHR
impl Clone for VkQueueFamilyProperties2KHR
Sourcefn clone(&self) -> VkQueueFamilyProperties2KHR
fn clone(&self) -> VkQueueFamilyProperties2KHR
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VkQueueFamilyProperties2KHR
impl Debug for VkQueueFamilyProperties2KHR
Sourceimpl TypedVulkanSinkStructure for VkQueueFamilyProperties2KHR
impl TypedVulkanSinkStructure for VkQueueFamilyProperties2KHR
Sourceconst TYPE: VkStructureType = 1_000_059_005i32
const TYPE: VkStructureType = 1_000_059_005i32
sType constant for this structure.Sourcefn uninit_sink() -> MaybeUninit<Self>
fn uninit_sink() -> MaybeUninit<Self>
Constructs an uninitialized cell for this structure, that is ready to pass the api
Sourcefn try_from_generic(g: &GenericVulkanSinkStructure) -> Option<&Self>
fn try_from_generic(g: &GenericVulkanSinkStructure) -> Option<&Self>
Cast structure ref only if sType matches
Sourceimpl VulkanSinkStructure for VkQueueFamilyProperties2KHR
impl VulkanSinkStructure for VkQueueFamilyProperties2KHR
Sourcefn as_generic(&self) -> &GenericVulkanSinkStructure
fn as_generic(&self) -> &GenericVulkanSinkStructure
Cast this structure ref to generic one. This is same as transmute but must be safe.
Sourcefn as_generic_mut(&mut self) -> &mut GenericVulkanSinkStructure
fn as_generic_mut(&mut self) -> &mut GenericVulkanSinkStructure
Cast this structure mutable ref to generic one. This is same as transmute but must be safe.