#[repr(C)]pub struct VkRenderPassCreateInfo {
pub sType: VkStructureType,
pub pNext: *const c_void,
pub flags: VkRenderPassCreateFlags,
pub attachmentCount: u32,
pub pAttachments: *const VkAttachmentDescription,
pub subpassCount: u32,
pub pSubpasses: *const VkSubpassDescription,
pub dependencyCount: u32,
pub pDependencies: *const VkSubpassDependency,
}Fields
sType: VkStructureTypepNext: *const c_voidflags: VkRenderPassCreateFlagsattachmentCount: u32pAttachments: *const VkAttachmentDescriptionsubpassCount: u32pSubpasses: *const VkSubpassDescriptiondependencyCount: u32pDependencies: *const VkSubpassDependencyTrait Implementations
Sourceimpl Clone for VkRenderPassCreateInfo
impl Clone for VkRenderPassCreateInfo
Sourcefn clone(&self) -> VkRenderPassCreateInfo
fn clone(&self) -> VkRenderPassCreateInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VkRenderPassCreateInfo
impl Debug for VkRenderPassCreateInfo
Sourceimpl TypedVulkanStructure for VkRenderPassCreateInfo
impl TypedVulkanStructure for VkRenderPassCreateInfo
Sourceconst TYPE: VkStructureType = 38i32
const TYPE: VkStructureType = 38i32
sType of this structure
Sourcefn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
fn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
Cast structure ref only if sType matches
Sourceimpl VulkanStructure for VkRenderPassCreateInfo
impl VulkanStructure for VkRenderPassCreateInfo
Sourcefn as_generic(&self) -> &GenericVulkanStructure
fn as_generic(&self) -> &GenericVulkanStructure
Cast structure ref to generic. This is same as transmute but must be safe.
Sourcefn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
fn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
Cast structure mutable ref to generic. This is same as transmute but must be safe.