#[repr(C)]pub struct VkSemaphoreCreateInfo {
pub sType: VkStructureType,
pub pNext: *const c_void,
pub flags: VkSemaphoreCreateFlags,
}Fields
sType: VkStructureTypepNext: *const c_voidflags: VkSemaphoreCreateFlagsTrait Implementations
Sourceimpl Clone for VkSemaphoreCreateInfo
impl Clone for VkSemaphoreCreateInfo
Sourcefn clone(&self) -> VkSemaphoreCreateInfo
fn clone(&self) -> VkSemaphoreCreateInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VkSemaphoreCreateInfo
impl Debug for VkSemaphoreCreateInfo
Sourceimpl TypedVulkanStructure for VkSemaphoreCreateInfo
impl TypedVulkanStructure for VkSemaphoreCreateInfo
Sourceconst TYPE: VkStructureType = 9i32
const TYPE: VkStructureType = 9i32
sType of this structure
Sourcefn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
fn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
Cast structure ref only if sType matches
Sourceimpl VulkanStructure for VkSemaphoreCreateInfo
impl VulkanStructure for VkSemaphoreCreateInfo
Sourcefn as_generic(&self) -> &GenericVulkanStructure
fn as_generic(&self) -> &GenericVulkanStructure
Cast structure ref to generic. This is same as transmute but must be safe.
Sourcefn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
fn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
Cast structure mutable ref to generic. This is same as transmute but must be safe.