#[repr(C)]pub struct VkSemaphoreSubmitInfoKHR {
pub sType: VkStructureType,
pub pNext: *const c_void,
pub semaphore: VkSemaphore,
pub value: u64,
pub stageMask: VkPipelineStageFlags2KHR,
pub deviceIndex: u32,
}Fields
sType: VkStructureTypepNext: *const c_voidsemaphore: VkSemaphorevalue: u64stageMask: VkPipelineStageFlags2KHRdeviceIndex: u32Trait Implementations
Sourceimpl Clone for VkSemaphoreSubmitInfoKHR
impl Clone for VkSemaphoreSubmitInfoKHR
Sourcefn clone(&self) -> VkSemaphoreSubmitInfoKHR
fn clone(&self) -> VkSemaphoreSubmitInfoKHR
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VkSemaphoreSubmitInfoKHR
impl Debug for VkSemaphoreSubmitInfoKHR
Sourceimpl TypedVulkanStructure for VkSemaphoreSubmitInfoKHR
impl TypedVulkanStructure for VkSemaphoreSubmitInfoKHR
Sourceconst TYPE: VkStructureType = 1_000_314_005i32
const TYPE: VkStructureType = 1_000_314_005i32
sType of this structure
Sourcefn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
fn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
Cast structure ref only if sType matches
Sourceimpl VulkanStructure for VkSemaphoreSubmitInfoKHR
impl VulkanStructure for VkSemaphoreSubmitInfoKHR
Sourcefn as_generic(&self) -> &GenericVulkanStructure
fn as_generic(&self) -> &GenericVulkanStructure
Cast structure ref to generic. This is same as transmute but must be safe.
Sourcefn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
fn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
Cast structure mutable ref to generic. This is same as transmute but must be safe.