#[repr(C)]pub struct VkSubmitInfo {
pub sType: VkStructureType,
pub pNext: *const c_void,
pub waitSemaphoreCount: u32,
pub pWaitSemaphores: *const VkSemaphore,
pub pWaitDstStageMask: *const VkPipelineStageFlags,
pub commandBufferCount: u32,
pub pCommandBuffers: *const VkCommandBuffer,
pub signalSemaphoreCount: u32,
pub pSignalSemaphores: *const VkSemaphore,
}Fields
sType: VkStructureTypepNext: *const c_voidwaitSemaphoreCount: u32pWaitSemaphores: *const VkSemaphorepWaitDstStageMask: *const VkPipelineStageFlagscommandBufferCount: u32pCommandBuffers: *const VkCommandBuffersignalSemaphoreCount: u32pSignalSemaphores: *const VkSemaphoreTrait Implementations
Sourceimpl Clone for VkSubmitInfo
impl Clone for VkSubmitInfo
Sourcefn clone(&self) -> VkSubmitInfo
fn clone(&self) -> VkSubmitInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VkSubmitInfo
impl Debug for VkSubmitInfo
Sourceimpl TypedVulkanStructure for VkSubmitInfo
impl TypedVulkanStructure for VkSubmitInfo
Sourceconst TYPE: VkStructureType = 4i32
const TYPE: VkStructureType = 4i32
sType of this structure
Sourcefn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
fn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
Cast structure ref only if sType matches
Sourceimpl VulkanStructure for VkSubmitInfo
impl VulkanStructure for VkSubmitInfo
Sourcefn as_generic(&self) -> &GenericVulkanStructure
fn as_generic(&self) -> &GenericVulkanStructure
Cast structure ref to generic. This is same as transmute but must be safe.
Sourcefn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
fn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
Cast structure mutable ref to generic. This is same as transmute but must be safe.