#[repr(C)]pub struct VkSubmitInfo2KHR {
pub sType: VkStructureType,
pub pNext: *const c_void,
pub flags: VkSubmitFlagsKHR,
pub waitSemaphoreInfoCount: u32,
pub pWaitSemaphoreInfos: *const VkSemaphoreSubmitInfoKHR,
pub commandBufferInfoCount: u32,
pub pCommandBufferInfos: *const VkCommandBufferSubmitInfoKHR,
pub signalSemaphoreInfoCount: u32,
pub pSignalSemaphoreInfos: *const VkSemaphoreSubmitInfoKHR,
}Fields
sType: VkStructureTypepNext: *const c_voidflags: VkSubmitFlagsKHRwaitSemaphoreInfoCount: u32pWaitSemaphoreInfos: *const VkSemaphoreSubmitInfoKHRcommandBufferInfoCount: u32pCommandBufferInfos: *const VkCommandBufferSubmitInfoKHRsignalSemaphoreInfoCount: u32pSignalSemaphoreInfos: *const VkSemaphoreSubmitInfoKHRTrait Implementations
Sourceimpl Clone for VkSubmitInfo2KHR
impl Clone for VkSubmitInfo2KHR
Sourcefn clone(&self) -> VkSubmitInfo2KHR
fn clone(&self) -> VkSubmitInfo2KHR
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VkSubmitInfo2KHR
impl Debug for VkSubmitInfo2KHR
Sourceimpl TypedVulkanStructure for VkSubmitInfo2KHR
impl TypedVulkanStructure for VkSubmitInfo2KHR
Sourceconst TYPE: VkStructureType = 1_000_314_004i32
const TYPE: VkStructureType = 1_000_314_004i32
sType of this structure
Sourcefn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
fn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
Cast structure ref only if sType matches
Sourceimpl VulkanStructure for VkSubmitInfo2KHR
impl VulkanStructure for VkSubmitInfo2KHR
Sourcefn as_generic(&self) -> &GenericVulkanStructure
fn as_generic(&self) -> &GenericVulkanStructure
Cast structure ref to generic. This is same as transmute but must be safe.
Sourcefn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
fn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
Cast structure mutable ref to generic. This is same as transmute but must be safe.