#[repr(C)]pub struct VkSurfaceCapabilitiesKHR {
pub minImageCount: u32,
pub maxImageCount: u32,
pub currentExtent: VkExtent2D,
pub minImageExtent: VkExtent2D,
pub maxImageExtent: VkExtent2D,
pub maxImageArrayLayers: u32,
pub supportedTransforms: VkSurfaceTransformFlagsKHR,
pub currentTransform: VkSurfaceTransformFlagBitsKHR,
pub supportedCompositeAlpha: VkCompositeAlphaFlagsKHR,
pub supportedUsageFlags: VkImageUsageFlags,
}Fields
minImageCount: u32maxImageCount: u32currentExtent: VkExtent2DminImageExtent: VkExtent2DmaxImageExtent: VkExtent2DmaxImageArrayLayers: u32supportedTransforms: VkSurfaceTransformFlagsKHRcurrentTransform: VkSurfaceTransformFlagBitsKHRsupportedCompositeAlpha: VkCompositeAlphaFlagsKHRsupportedUsageFlags: VkImageUsageFlagsImplementations
Sourceimpl VkSurfaceCapabilitiesKHR
impl VkSurfaceCapabilitiesKHR
Sourcepub const fn supported_transforms(&self) -> SurfaceTransformFlags
pub const fn supported_transforms(&self) -> SurfaceTransformFlags
The presentation transforms supported for the surface
Sourcepub const fn current_transform(&self) -> SurfaceTransformFlags
pub const fn current_transform(&self) -> SurfaceTransformFlags
The surface’s current transform relative to the presentation engine’s natural orientation
Sourcepub const fn supported_composite_alpha(&self) -> CompositeAlphaFlags
pub const fn supported_composite_alpha(&self) -> CompositeAlphaFlags
The alpha compositing modes supported by the presentation engine for the surface
Sourcepub const fn supported_usage_flags(&self) -> ImageUsageFlags
pub const fn supported_usage_flags(&self) -> ImageUsageFlags
The ways the application can use the presentable images of a swapchain