#[repr(C)]pub struct VkSwapchainCreateInfoKHR {Show 18 fields
pub sType: VkStructureType,
pub pNext: *const c_void,
pub flags: VkSwapchainCreateFlagsKHR,
pub surface: VkSurfaceKHR,
pub minImageCount: u32,
pub imageFormat: VkFormat,
pub imageColorSpace: VkColorSpaceKHR,
pub imageExtent: VkExtent2D,
pub imageArrayLayers: u32,
pub imageUsage: VkImageUsageFlags,
pub imageSharingMode: VkSharingMode,
pub queueFamilyIndexCount: u32,
pub pQueueFamilyIndices: *const u32,
pub preTransform: VkSurfaceTransformFlagBitsKHR,
pub compositeAlpha: VkCompositeAlphaFlagBitsKHR,
pub presentMode: VkPresentModeKHR,
pub clipped: VkBool32,
pub oldSwapchain: VkSwapchainKHR,
}Fields
sType: VkStructureTypepNext: *const c_voidflags: VkSwapchainCreateFlagsKHRsurface: VkSurfaceKHRminImageCount: u32imageFormat: VkFormatimageColorSpace: VkColorSpaceKHRimageExtent: VkExtent2DimageArrayLayers: u32imageUsage: VkImageUsageFlagsimageSharingMode: VkSharingModequeueFamilyIndexCount: u32pQueueFamilyIndices: *const u32preTransform: VkSurfaceTransformFlagBitsKHRcompositeAlpha: VkCompositeAlphaFlagBitsKHRpresentMode: VkPresentModeKHRclipped: VkBool32oldSwapchain: VkSwapchainKHRTrait Implementations
Sourceimpl Clone for VkSwapchainCreateInfoKHR
impl Clone for VkSwapchainCreateInfoKHR
Sourcefn clone(&self) -> VkSwapchainCreateInfoKHR
fn clone(&self) -> VkSwapchainCreateInfoKHR
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VkSwapchainCreateInfoKHR
impl Debug for VkSwapchainCreateInfoKHR
Sourceimpl TypedVulkanStructure for VkSwapchainCreateInfoKHR
impl TypedVulkanStructure for VkSwapchainCreateInfoKHR
Sourceconst TYPE: VkStructureType = 1_000_001_000i32
const TYPE: VkStructureType = 1_000_001_000i32
sType of this structure
Sourcefn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
fn try_from_generic(g: &GenericVulkanStructure) -> Option<&Self>
Cast structure ref only if sType matches
Sourceimpl VulkanStructure for VkSwapchainCreateInfoKHR
impl VulkanStructure for VkSwapchainCreateInfoKHR
Sourcefn as_generic(&self) -> &GenericVulkanStructure
fn as_generic(&self) -> &GenericVulkanStructure
Cast structure ref to generic. This is same as transmute but must be safe.
Sourcefn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
fn as_generic_mut(&mut self) -> &mut GenericVulkanStructure
Cast structure mutable ref to generic. This is same as transmute but must be safe.